# Supercell

Supercell is a library for pulling various kinds of weather, satellite, and highway data from various APIs.

Currently all of the highway conditions code is specific to Colorado where I am currently located.

## Installation

How to Install Supercell

## Testing

How to run and write new tests.

## Contributing

How to contribute.
